jaclearn.dataflow.batch
=======================

.. automodule:: jaclearn.dataflow.batch

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      BatchDataFlow
      EpochDataFlow
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      batch_default_filler
   
   

   
   
   








.. rubric:: Class BatchDataFlow
.. autoclass:: BatchDataFlow
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class EpochDataFlow
.. autoclass:: EpochDataFlow
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: batch_default_filler


